@@ -24,31 +24,6 @@ my (
   );
 
 
-if ($>) {
-  $blackboxrc = "$home/.blackboxrc";
-
-  if (!-e $blackboxrc) {
-    print "This looks like your first time running Blackbox.  Please restart Blackbox\n";
-    print "from the root menu so I can tell what themes are available.\n";
-    finish();
-  }
-
-  $mainmenu = readrc_blackbox();
-  if (!$mainmenu) {
-    print "No menu is indicated in your .blackboxrc.  Please restart Blackbox\n";
-    print "from the root menu so I can tell what themes are available.\n";
-    finish();
-  }
-  if (! -e $mainmenu) {
-    complainmenu_blackbox($mainmenu);
-  }
-
-  $styledirs = {};
-  include_wmcode('wm_data.pl');
-  scanmenu_blackbox($mainmenu, $styledirs, {});
-}
-
-
   ##
   #
   #  WM_GETDEFAULTDIRS
@@ -60,8 +35,29 @@ if ($>) {
 
 sub wm_getdefaultdirs {
   if ($>) {
+    $blackboxrc = "$home/.blackboxrc";
+  
+    if (!-e $blackboxrc) {
+      print "This looks like your first time running Blackbox.  Please restart Blackbox\n";
+      print "from the root menu so I can tell what themes are available.\n";
+      finish();
+    }
+  
+    $mainmenu = readrc_blackbox();
+    if (!$mainmenu) {
+      print "No menu is indicated in your .blackboxrc.  Please restart Blackbox\n";
+      print "from the root menu so I can tell what themes are available.\n";
+      finish();
+    }
+
+    complainmenu_blackbox($mainmenu) unless -e $mainmenu;
+  
+    $styledirs = {};
+    scanmenu_blackbox($mainmenu, $styledirs, {});
     keys %$styledirs;
+
   } else {
+
     verify_themedirs(0,
       '/usr/local/share/Blackbox/styles',   #  source tarball
       '/usr/share/blackbox/styles',         #  Debian
@@ -100,7 +96,7 @@ sub wm_scandir {
 sub wm_installtheme {
   my ($tempdir, $filename, $defname) = @_;
   my ($dest_style, $dest_bg, $rootcommand_destbg,
-    $menutext, @files, @filetypes, $i, $stylefile, $bgimage, $theme,
+    @files, @filetypes, $i, $stylefile, $bgimage, $theme,
     $includedest, $specified_bg, $specified_base, @bgcandidates);
 
   getversion_blackbox();
@@ -146,10 +142,7 @@ sub wm_installtheme {
     $dest_style = $globalthemedir;
   }
 
-  if ($debug) {
-    dbugout("WM_INSTALLTHEME: style dir is $dest_style");
-    dbugout("WM_INSTALLTHEME: bg dir is $dest_bg");
-  }
+  dbugout("style dir is $dest_style", "bg dir is $dest_bg") if $debug;
 
    #=========================================================================
    # Examine files and move to destinations
@@ -181,22 +174,17 @@ sub wm_installtheme {
     }
   }
 
-  if (!$stylefile) {
-    choke('theme contains no style file');
-  } elsif ($debug) {
-    dbugout("WM_INSTALLTHEME: style file is $stylefile");
-  }
+  choke('theme contains no style file') unless $stylefile;
+
+  dbugout("style file is $stylefile") if $debug;
 
   if ($defname) {
     $theme = $defname;
   } else {
     ($theme = $stylefile) =~ s!.*/!!;
-    if (!$theme) {
-      ($theme = $filename) =~ s!\..*$!!;
-    }
-    if (!$theme) {
-      choke("strange, I cannot get a theme name from \"$stylefile\" or \"$filename\"");
-    }
+    ($theme = $filename) =~ s/\..*$// unless $theme;
+    choke("strange, I cannot get a theme name from \"$stylefile\" or \"$filename\"")
+      unless $theme;
   }
   $theme = checkname($theme);
 
@@ -211,23 +199,22 @@ sub wm_installtheme {
 
   if (!$>) {
     if (-f "$dest_style/stylesmenu") {
-      $menutext = styleentry_blackbox($theme) .
-        slurpfile("$dest_style/stylesmenu");
-      stowfile("$dest_style/stylesmenu", $menutext);
+      stowfile("$dest_style/stylesmenu",
+        styleentry_blackbox($theme) . slurpfile("$dest_style/stylesmenu"));
     }
   } elsif (!$dirusage{$dest_style}) {
 
-    dbugout("WM_INSTALLTHEME: style goes into a _new_ [stylesdir]") if $debug;
+    dbugout("style goes into a _new_ [stylesdir]") if $debug;
     addtostylesmenu_blackbox("    [stylesdir] (" .
       bbmenuescape($dest_style) . ")\n");
 
   } elsif ($dirusage{$dest_style} =~ /^include:(.+)/) {
 
     $includedest = $1;
-    dbugout("WM_INSTALLTHEME: menu item goes into file $includedest") if $debug;
-    $menutext = styleentry_blackbox($theme) .
-      slurpfile($includedest);
-    stowfile($includedest, $menutext);
+    dbugout("menu item goes into file $includedest") if $debug;
+
+    stowfile($includedest,
+      styleentry_blackbox($theme) . slurpfile($includedest));
 
       ## If this included fragment was empty, Blackbox won't check it
       ## and the new theme won't show up in the menu.  By touching
@@ -236,7 +223,8 @@ sub wm_installtheme {
 
       ## Since [include]s that actually contain something will be
       ## checked, we won't need to touch anything when uninstalling.
-    touch($mainmenu);  
+    my $now = time;
+    utime $now, $now, $mainmenu;
 
   } elsif ($dirusage{$dest_style} eq 'style') {
 
@@ -244,8 +232,7 @@ sub wm_installtheme {
 
   } elsif ($dirusage{$dest_style} eq 'stylesdir') {
 
-    dbugout("WM_INSTALLTHEME: style goes into an existing [stylesdir]")
-      if $debug;
+    dbugout("style goes into an existing [stylesdir]") if $debug;
 
   } else {
 
@@ -264,11 +251,8 @@ sub wm_activatetheme {
   # abort if $blackboxrc not writable
 
   unless (-w $blackboxrc) {
-    if ($explicit) {
-      choke("Can't activate themes: $blackboxrc isn't writable.");
-    } else {
-      return;
-    }
+    choke("Can't activate themes: $blackboxrc isn't writable.") if $explicit;
+    return;
   }
 
   # modify it to indicate desired theme
@@ -282,7 +266,7 @@ sub wm_activatetheme {
 
   # send signal
 
-  sigbyname('USR1', $wm_executable);
+  sigbyname(USR1, $wm_executable);
 }
 
   ##
@@ -308,7 +292,7 @@ sub wm_uninstalltheme {
 
   if ($bgimage = identifybgfile_blackbox($themes{$theme}{path})) {
     unlink expandhomedir($bgimage);
-    dbugout("WM_UNINSTALLTHEME: erased background image $bgimage") if $debug;
+    dbugout("erased background image $bgimage") if $debug;
   }
 
   unlink $themes{$theme}{path};
@@ -366,8 +350,7 @@ sub wm_versionok {
 
   if ($blackbox_version and $request =~ /(\d+\.\d+)/) {
     $rqver = $1;
-    dbugout("WM_VERSIONOK: checking $rqver against Blackbox v$blackbox_version")
-      if $debug;
+    dbugout("checking $rqver against Blackbox v$blackbox_version") if $debug;
     if ($blackbox_version < 0.6) {
       return $rqver < 0.6;
     } elsif ($blackbox_version < 0.7) {
@@ -377,8 +360,7 @@ sub wm_versionok {
       return 1;
     }
   } else {
-    dbugout("WM_VERSIONOK: incomprehensible version \"$request\": returning ok")
-      if $debug;
+    dbugout("incomprehensible version \"$request\": returning ok") if $debug;
     return 1;
   }
 }
@@ -395,7 +377,7 @@ sub fixstyle_blackbox {
     $bgcmd, $err, $foundrootcmd, $true_bgimage, $valid_rootcommands);
 
   open F, $stylefile or return;
-  while (defined ($line = nextstyleline_blackbox(\*F, 0))) {
+  while (defined ($line = readcontinuationline(\*F, 0))) {
 
     if ($foundrootcmd) {
 
@@ -421,8 +403,7 @@ sub fixstyle_blackbox {
             ($bgbase = $_) =~ s!.*/!!;
             if ($bgbase and $bgbase eq $imgbase) {
               $true_bgimage = $_;
-              dbugout("FIXSTYLE_BLACKBOX: background image is $true_bgimage")
-                if $debug;
+              dbugout("background image is $true_bgimage") if $debug;
               last;
             }
           }
@@ -492,18 +473,18 @@ sub fixstyle_blackbox {
 sub parserootcommand_blackbox {
   my $rootcommand = shift;
 
-  dbugout("PRC: looking at $rootcommand") if $debug;
+  dbugout("looking at $rootcommand") if $debug;
 
   $rootcommand =~ s!^/\S*/!!;  # remove path from utility
 
   if ($rootcommand =~ /(^|^.+?\s)((?:~|\.?\.?\/).+?\/.+|\/.+)(\s.+|)$/) {
-    dbugout("PRC: returning (1)  [$1] [$3] [$2]") if $debug;
+    dbugout("returning (1)  [$1] [$3] [$2]") if $debug;
     return $1, $3, $2;
   } elsif ($rootcommand =~ /(^|^.+?\s")((?:~|\.?\.?\/).+?\/.+|\/.+[^\\])("\s.+|")$/) {
-    dbugout("PRC: returning (2)  [$1] [$3] [$2]") if $debug;
+    dbugout("returning (2)  [$1] [$3] [$2]") if $debug;
     return $1, $3, $2;
   }
-  dbugout("PRC: didn't match.") if $debug;
+  dbugout("didn't match.") if $debug;
   ('', '', '');
 }
 
@@ -644,7 +625,7 @@ sub scanmenu_blackbox {
   my ($menutext, @includes, $line, $dir);
 
   open (F, $menu) or return;
-  dbugout("SCANMENU_BLACKBOX: reading $menu") if $debug;
+  dbugout("reading $menu") if $debug;
 
   while (defined($line = <F>)) {
     next if $line =~ /^\s*#/;
@@ -657,7 +638,7 @@ sub scanmenu_blackbox {
       ($dir = $path) =~ s!/[^/]*$!!;
 
       if (-f $path) {
-        dbugout("SCANMENU_BLACKBOX: adding \"$name\" from [style] entry") if $debug;
+        dbugout("adding \"$name\" from [style] entry") if $debug;
         setdirusage_blackbox($dir, 'style', '') if $menu eq $mainmenu;
         createthemerec($name, $path, (stat _)[4]);
         $menufile{$name} = $menu;
@@ -665,7 +646,7 @@ sub scanmenu_blackbox {
         setdirusage_blackbox($dir, 'style', '');
         $$styledirs{$dir} = 1;
       } else {
-        dbugout("SCANMENU_BLACKBOX: not adding \"$name\" from invalid [style] entry")
+        dbugout("not adding \"$name\" from invalid [style] entry")
           if $debug;
       }
     } elsif ($line =~ /\[\s*include\s*\]\s*\((.+)\)\s*$/) {
@@ -676,7 +657,7 @@ sub scanmenu_blackbox {
       if ($$rccheck{$path}) {
         complain("warning: repeated [include] for \"$path\"");
       } elsif (-f $path) {
-        dbugout("SCANMENU_BLACKBOX: include $path") if $debug;
+        dbugout("include $path") if $debug;
         setdirusage_blackbox($dir, 'include', $path) if $menu eq $mainmenu;
         push @includes, $path;
         $$rccheck{$path} = 1;
@@ -694,11 +675,11 @@ sub scanmenu_blackbox {
         print "$programname: restart Blackbox so it will scan this directory.\n";
       }
       if (-d $path) {
-        dbugout("SCANMENU_BLACKBOX: stylesdir $path") if $debug;
+        dbugout("stylesdir $path") if $debug;
         setdirusage_blackbox($path, 'stylesdir', '');
         $$styledirs{$path} = 1;
       } else {
-        dbugout("SCANMENU_BLACKBOX: not including invalid stylesdir $path")
+        dbugout("not including invalid stylesdir $path")
           if $debug;
       }
     }
@@ -733,14 +714,12 @@ sub setdirusage_blackbox {
 sub getversion_blackbox {
   return if defined $blackbox_version;
 
-  if (`blackbox -version` =~ /^\S+\s+((\d+)\.(\d+))/) {
+  if (`blackbox -version` =~ /\b((\d+)\.(\d+))/) {
     $blackbox_version = $1;
-    dbugout("GETVERSION_BLACKBOX: version recorded as $blackbox_version")
-      if $debug;
+    dbugout("version recorded as $blackbox_version") if $debug;
   } else {
     $blackbox_version = 0;
-    dbugout("GETVERSION_BLACKBOX: couldn't determine version!")
-      if $debug;
+    dbugout("couldn't determine version!") if $debug;
   }
 }
 
@@ -755,7 +734,7 @@ sub identifybgfile_blackbox {
   my $line;
 
   open F, $stylefile or return;
-  while (defined ($line = nextstyleline_blackbox(\*F, 1))) {
+  while (defined ($line = readcontinuationline(\*F, 1))) {
     if ($line =~ /^\s*rootcommand\s*:\s*(.+?)\s*$/i) {
       (undef, undef, $bgimage) = parserootcommand_blackbox($1);
       last;
@@ -765,20 +744,6 @@ sub identifybgfile_blackbox {
   $bgimage;
 }
 
-
-sub nextstyleline_blackbox {
-  my ($fh, $stripbs) = @_;
-  my ($line, $in);
-
-  return unless defined($line = <$fh>);
-
-  $line .= $in while $line =~ /\\$/ and defined($in = <$fh>);
-
-  $line =~ s/\\(?:\n|$)//gs if $stripbs;
-
-  $line;
-}
-
 sub bbmenuescape {
   my $text = shift;
   $text =~ s/([(){}])/\\$1/g;
